process.env.TZ = "Asia/Kolkata"
require('dotenv').config()
const corsConfig = require('./controller/CorsConfig')
const express = require('express')
const helmet = require("helmet");
const router = express.Router()
const app = express()
const { LoginRoutes, PostRoutes, DashboardRoutes, ClientRoutes } = require('./routes/index')
// const cors = require('cors')
const multer = require('multer')
const HELPER = require('./controller/helpers').Helpers
const upload = require('./controller/uploadConfig')
const receive = multer()
require('./helpers/protoType')
const { isAuthorizeUser, isAuthorizedBot, isAuthorizedAny } = require('./controller/authentication');
const ExtraRoutes = require('./routes/ExtraRoutes');
const UsersRoute = require('./routes/UsersRoute');

process.env.CSV_UPLOAD_PATH = __dirname + '/uploads/'
process.env.CSV_UPLOAD_URI = 'https://api.ayurvedalifecare.in/uploads/'
process.env.UPLOAD_PATH =
    typeof process.env.UPLOAD_PATH != "undefined" ?
        process.env.UPLOAD_PATH :
        '/home/ayurvedalife15/public_html/staticcontent/'
process.env.UPLOAD_URL =
    typeof process.env.UPLOAD_URL != "undefined" ?
        process.env.UPLOAD_URL :
        'http://staticcontent.ayurvedalifecare.in/'

app.use(helmet());
app.use('/uploads', express.static('uploads'));
app.use(express.urlencoded({ extended: true }))
app.use(corsConfig);

app.use('/api', router)

router.get("/dashboard/", isAuthorizedAny, DashboardRoutes.fetchData)
router.get("/fetch/category/", isAuthorizeUser, PostRoutes.category)
router.get("/fetch/product/", isAuthorizeUser, PostRoutes.products)
//router.get("/fetch/language/", isAuthorizeUser, PostRoutes.languages)
router.get("/fetch/post/", isAuthorizeUser, PostRoutes.fetchPost)
router.get("/fetch/post/:postid", isAuthorizeUser, PostRoutes.fetchPostDetail)
router.get("/fetch/blog/:blogname", PostRoutes.fetchBlogDetail)
router.get("/fetch/formdata/", isAuthorizeUser, DashboardRoutes.fetchFormData)
router.get("/syncdata", isAuthorizedBot, ClientRoutes.syncdata)
router.get("/option/:key", ClientRoutes.fetchOption)
router.get("/logs/view", isAuthorizeUser, ExtraRoutes.fetchLogs)
router.get("/users/view", isAuthorizeUser, UsersRoute.fetchUsers)


router.post("/post/blog_redirection", isAuthorizeUser,receive.any(),PostRoutes.Redirection_updater )
router.get("/post/redirection-reserved", isAuthorizeUser,receive.any(),PostRoutes.getBlogRedirection )
router.post("/post/edit/blog_redirection", isAuthorizeUser,receive.any(),PostRoutes.Redirection_edit )
router.post("/post/add/blog_redirection", isAuthorizeUser,receive.any(),PostRoutes.AddBlogRedirection )
router.post("/login", receive.any(), LoginRoutes)
router.post("/upload/image/", isAuthorizeUser, upload.single('post_image'), PostRoutes.uploadImage)
router.post("/post/create/", isAuthorizeUser, receive.any(), PostRoutes.newPost)
router.post("/users/update/:key", isAuthorizeUser, receive.any(), UsersRoute.updateUser)
router.post("/users/add", isAuthorizeUser, receive.any(), UsersRoute.addUser)
router.post("/post/create/category", isAuthorizeUser, receive.any(), PostRoutes.newcat)
router.post("/create/inquiry", receive.any(), ClientRoutes.createInquiry)
router.post("/create/product", receive.any(), PostRoutes.newproduct)
router.post("/update/post/:post_id", isAuthorizeUser, receive.any(), PostRoutes.editPost)
router.post("/delete/post/:post_id", isAuthorizeUser, receive.any(), PostRoutes.deletePost)



router.all('*', function (req, res) {
    return res
        .status(400)
        .json(HELPER.sendResponse(
            "fail", [],
            "Route Undefined"
        ))
})

app.listen(process.env.PORT || 8080)