const { Helpers } = require('../controller/helpers');
const { ClientModel, DashboardModel, PostModel, ExtraModel } = require('../controller/index')
const moment = require('moment')

const convertToLead = (d) => {
    const today = new Date()
    const name = (new Date(`${today.getFullYear()}-${today.getMonth() + 1}-${today.getDate()}`).getTime() / 1000)
    return {
        file_id: name,
        lead_id: `${name}_${today.getFullYear()}_${today.getMonth() + 1}_${today.getDate()}`,
        full_name: d.full_name.trim(),
        mobile_one: d.mobile_one.trim(),
        address: d.address.trim(),
        language: d.language,
        product: d.product,
        inquiry_date: moment(d.inquiry_date).format('DD-MMM-YYYY'),
        inquiry_timestamp: d.inquiry_date,
        form_id: d.form_id
    }
}


module.exports = {
    syncdata: async function (req, res) {
        const count = req.query.count
        try {
            const response = await DashboardModel.fetchPendingLeads(req.query.formid, typeof count !== 'undefined' && count === 'true')
            
            if (response.length > 0) {
                const leads = response.map(lead => convertToLead(lead))
                //console.log(leads)
                return res.status(200).json(leads)
            }
            return res.status(404).json({ message: 'No data to transfer' })
        } catch (error) {
            //console.log(error)
            ExtraModel.localLog(error)
            return res.status(500).json({ message: 'Something went wrong' })
        }
    },
    fetchOption: async function (req, res) {
        let { key } = req.params
        key = key.split(",")
        const response = await ClientModel.fetch(key)
        //console.log(response)
        return res.status(200).json(Helpers.sendResponse("success", response, `Option Fetch Successfully`))
    },
    createInquiry: async function (req, res) {
        let REQUIRED = ["form_name", "form_number", "form_address", "form_blogname", "ip_array"]
        let FIELD_GET = Object.keys(req.body)
        if (REQUIRED.isEqualArray(FIELD_GET)) {
            let { form_name, form_number, form_address, form_blogname, ip_array } = req.body
            var tres = await ClientModel.validateInquiry(form_number)
            if (typeof tres.length !== 'undefined' && tres.length > 0) {
                return res.status(409).json(Helpers.sendResponse("fail", [], `Inquiry already generated`))
            } else {
                let create = {
                    form_name: form_name.escapeString(),
                    form_number,
                    form_address: form_address.escapeString(),
                    form_blogname,
                    submit_ip: ip_array,
                }
                const result = await ClientModel.create(create)
                if (result.affectedRows > 0) {
                    return res.status(200).json(Helpers.sendResponse("success", [], `Created Successfully`))
                }
            }
            return res.status(400).json(Helpers.sendResponse("fail", [], `Something went wrong`))
        }
        return res.status(400).json(Helpers.sendResponse("fail", [], `Key Mismatch ${REQUIRED.join(",")}`))
    }
}