const { Helpers } = require('../controller/helpers');
const { ExtraModel, UserModel } = require('../controller/index')
const moment = require('moment');
const md5 = require('md5');


module.exports = {
    fetchUsers: async function (_, res) {
        try {
            const response = await UserModel.fetchUsers()
            return res.status(200).json({ data: response, message: 'Request successful' })
        } catch (error) {
            ExtraModel.localLog(error)
            return res.status(500).json({ message: 'Something went wrong' })
        }
    },
    addUser: async function (req, res) {
        const { username, email, password, role } = req.body
        //console.log(req.body)
        if (typeof username === 'undefined' || username === '' || typeof email === 'undefined' || email === '' || typeof password === 'undefined' || password === '' || typeof role === 'undefined' || role === '') {
            return res.status(400).json({ message: 'Required fields are missing!' })
        }
        const allowedRoles = ['bot', 'editor', 'administrator']
        //console.log(role)
        if (!allowedRoles.includes(role)) {
            return res.status(400).json({ message: 'Invalid role provided!' })
        }
        try {
            const result = await UserModel.createUser(username, email, password, role)
            //console.log(result)
            if (result.affectedRows > 0) {
                return res.status(200).json({ message: 'User added successfully' })
            } else {
                return res.status(500).json({ message: 'Failed to add user! Please try again.' })
            }
        } catch (error) {

            console.log(error)
            if (typeof error.code !== 'undefined' && error.code === 'ER_DUP_ENTRY') {
                return res.status(409).json({ message: 'Username and email must be unique!' })
            } else {
                ExtraModel.localLog(error)
                return res.status(500).json({ message: 'Something went wrong!' })
            }
        }
    },
    updateUser: async function (req, res) {
        const key = req.params.key
        if (key === 'password' || key === 'username') {
            const { userid, username, password, accessPass } = req.body

            if (key === 'username' && (typeof username === 'undefined' || username === '')) {
                return res.status(400).json({ message: 'Required fields are missing! (Username missing)' })
            }
            if (key === 'password' && (typeof password === 'undefined' || password === '')) {
                return res.status(400).json({ message: 'Required fields are missing! (Password missing)' })
            }
            if (typeof userid === 'undefined' || userid === '' || typeof accessPass === 'undefined' || accessPass === '') {
                return res.status(400).json({ message: 'Required fields are missing! (Userid or accessPass missing)' })
            }
            try {
                const { token } = req.query
                const userRes = await UserModel.fetchUsers(`token = "${token}" AND password = "${md5(accessPass)}"`, 1)
                const toUpdate = {}
                if (userRes.length > 0) {
                    if (typeof username !== 'undefined') {
                        toUpdate.user_name = username.trim();
                    }
                    if (typeof password !== 'undefined') {
                        toUpdate.password = md5(password.trim())
                    }
                    if (!Object.keys(toUpdate).length > 0) {
                        return res.status(400).json({ message: 'Required fields are missing!' })
                    }
                    const result = await UserModel.updateUser(toUpdate, 'user_id', userid)
                    //console.log(result)
                    if (typeof result.affectedRows !== 'undefined' && result.affectedRows > 0) {
                        return res.status(200).json({ message: 'Request successful' })
                    } else {
                        return res.status(400).json({ message: 'Invalid user id!' })
                    }
                } else {
                    return res.status(400).json({ message: 'Invalid access password' })
                }
            } catch (error) {
                //console.log(error)
                ExtraModel.localLog(error)
                return res.status(500).json({ message: 'Something went wrong!' })
            }
        } else {
            return res.status(400).json({ message: 'Can not update given column!' })
        }
    },
}